voice_search library
Classes
- VoiceSearchWidget
- A customizable voice search widget that enables speech recognition.
Typedefs
- VoiceSearchResultCallback = void Function(String result)
- A callback function type that is triggered when a voice search result is obtained. The recognized speech text is passed as a parameter.