VoiceSearchResultCallback typedef
VoiceSearchResultCallback =
void Function(String result)
A callback function type that is triggered when a voice search result is obtained. The recognized speech text is passed as a parameter.
Implementation
typedef VoiceSearchResultCallback = void Function(String result);